@@ -1,18 +1,19 @@
-#' Method that runs the KMeans_rcpp algorithm using the Euclidean metric to make
-#'  an external or internal validation of the cluster.
 #'
-#' @param dt matrix or data frame with the set of values to be applied to the
+#' Method that runs the kmeans_rcpp algorithm using the Euclidean metric to
+#' make an external or internal validation of the cluster.
+#'
+#' @param dt Matrix or data frame with the set of values to be applied to the
 #' algorithm.
-#' @param clusters is an integer that indexes the number of clusters we want to
-#' create.
-#' @param columnClass is an integer with the number of columns, for example if a
-#' dataset has five column, we can select column four to calculate validation.
-#' @param metric is a characters vector with the metrics avalaible in the
-#' package. The metrics implemented are: entropy, variation_information,
-#' precision,recall,f_measure,fowlkes_mallows_index,connectivity,dunn,
-#' silhouette.
 #'
-#' @return returns a list with both the internal and external evaluation of the
+#' @param clusters It's an integer that indexes the number of clusters we want to
+#' create.
+#'
+#' @param metric It's a characters vector with the metrics avalaible in the
+#' package. The metrics implemented are: Entropy, Variation_information,
+#' Precision,Recall,F_measure,Fowlkes_mallows_index,Connectivity,Dunn,
+#' Silhouette.
+#'
+#' @return Return a list with both the internal and external evaluation of the
 #' grouping.
 #'
 #' @keywords internal
@@ -22,6 +23,8 @@ kmeans_rcpp_method = function(dt, clusters, columnClass, metric) {
 
   start.time <- Sys.time()
 
+  on.exit(options(warn = -1))
+
   if ('data.frame' %in% class(dt))
     dt = as.matrix(dt)
 
@@ -84,19 +87,23 @@ kmeans_rcpp_method = function(dt, clusters, columnClass, metric) {
 
 }
 
-#' Method that runs the KMeans_arma algorithm using the Euclidean metric to make
-#'an external or internal validation of the cluster
 #'
-#' @param data matrix or data frame
-#' @param clusters number of clusters
-#' @param columnClass is an integer with the number of columns, for example if a
-#' dataset has five column, we can select column four to calculate validation
-#' @param metric metrics avalaible in the package. The metrics implemented are:
-#' entropy, variation_information,precision,recall,f_measure,
-#' fowlkes_mallows_index,connectivity,dunn,silhouette.
+#' Method that runs the kmeans_arma algorithm using the Euclidean metric to
+#' make an external or internal validation of the cluster.
 #'
-#' @return returns a list with both the internal and external evaluation of the
-#' grouping
+#' @param dt Matrix or data frame with the set of values to be applied to the
+#' algorithm.
+#'
+#' @param clusters It's an integer that indexes the number of clusters we want to
+#' create.
+#'
+#' @param metric It's a characters vector with the metrics avalaible in the
+#' package. The metrics implemented are: Entropy, Variation_information,
+#' Precision,Recall,F_measure,Fowlkes_mallows_index,Connectivity,Dunn,
+#' Silhouette.
+#'
+#' @return Return a list with both the internal and external evaluation of the
+#' grouping.
 #'
 #' @keywords internal
 #'
@@ -106,6 +113,8 @@ kmeans_arma_method = function(dt, clusters, columnClass, metric) {
 
   start.time <- Sys.time()
 
+  on.exit(options(warn = -1))
+
   if ('data.frame' %in% class(dt))
     dt = as.matrix(dt)
 
@@ -183,19 +192,23 @@ kmeans_arma_method = function(dt, clusters, columnClass, metric) {
 
 }
 
-#' Method that runs the MiniBatchKmeans algorithm using the Euclidean metric to
-#' make an external or internal validation of the cluster
 #'
-#' @param data matrix or data frame
-#' @param clusters number of clusters
-#' @param columnClass is an integer with the number of columns, for example if a
-#' dataset has five column, we can select column four to calculate validation
-#' @param metric metrics avalaible in the package. The metrics implemented are:
-#' entropy, variation_information,precision,recall,f_measure,
-#' fowlkes_mallows_index,connectivity,dunn,silhouette.
+#' Method that runs the mini_kmeans algorithm using the Euclidean metric to
+#' make an external or internal validation of the cluster.
 #'
-#' @return returns a list with both the internal and external evaluation of the
-#' grouping
+#' @param dt Matrix or data frame with the set of values to be applied to the
+#' algorithm.
+#'
+#' @param clusters It's an integer that indexes the number of clusters we want to
+#' create.
+#'
+#' @param metric It's a characters vector with the metrics avalaible in the
+#' package. The metrics implemented are: Entropy, Variation_information,
+#' Precision,Recall,F_measure,Fowlkes_mallows_index,Connectivity,Dunn,
+#' Silhouette.
+#'
+#' @return Return a list with both the internal and external evaluation of the
+#' grouping.
 #'
 #' @keywords internal
 #'
@@ -204,6 +217,8 @@ mini_kmeans_method = function(dt, clusters, columnClass, metric) {
 
   start.time <- Sys.time()
 
+  on.exit(options(warn = -1))
+
   if ('data.frame' %in% class(dt))
     dt = as.matrix(dt)
 
